/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colordialog', 'bg', {
	clear: 'Изчистване',
	highlight: 'Осветяване',
	options: 'Цветови опции',
	selected: 'Изберете цвят',
	title: 'Избор на цвят'
} );
